@@ -13,10 +13,6 @@ extensions = [
     'sphinxcontrib.napoleon',
     'numpydoc'
 ]
-if os.getenv('SPELLCHECK'):
-    extensions += 'sphinxcontrib.spelling',
-    spelling_show_suggestions = True
-    spelling_lang = 'en_US'
 
 source_suffix = '.rst'
 master_doc = 'index'
@@ -24,7 +20,7 @@ project = u'AACGM-v2 Python library'
 year = u'2019'
 author = u'Angeline G. Burrell, Christer van der Meeren, Karl M. Laundal'
 copyright = '{0}, {1}'.format(year, author)
-version = release = u'2.6.0'
+version = release = u'2.6.1'
 # on_rtd is whether we are on readthedocs.org
 on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
 
